package com.ruoyi.cms.service;

import com.ruoyi.cms.domain.SensitiveWordData;

import java.util.List;

/**
 * 敏感词库
 *
 * @author 
 * @email 
 * @date 2025-10-10 10:42:16
 */
public interface SensitiveWordDataService {

    List<SensitiveWordData> selectSensitiveworddataList(SensitiveWordData sensitiveworddata);

    SensitiveWordData selectById(Long id);

    int insertSensitiveworddata(SensitiveWordData sensitiveWordData);

    int updateSensitiveworddata(SensitiveWordData sensitiveWordData);

    int deleteSensitiveworddataIds(Long[] ids);

    int batchInsert(List<SensitiveWordData> list);
}

